Crate codex_feedback

Crate codex_feedback 

Structs

CodexFeedback
FeedbackAttachment
In-memory attachment to include in a feedback upload.
FeedbackAttachmentPath
FeedbackDiagnostic
FeedbackDiagnostics
FeedbackMakeWriter
FeedbackRequestTags
Structured request/auth fields that should be attached to feedback uploads.
FeedbackSnapshot
FeedbackUploadOptions
Inputs that control one feedback upload to Sentry.
FeedbackWriter

Constants

CODEX_APPS_TOOLS_CACHE_ATTACHMENT_FILENAME
Filename used for the raw Codex Apps MCP tools cache feedback attachment.
CODEX_APP_DIRECTORY_CACHE_ATTACHMENT_FILENAME
Filename used for the raw connector directory cache feedback attachment.
DOCTOR_REPORT_ATTACHMENT_FILENAME
Filename used for the redacted codex doctor --json feedback attachment.
FEEDBACK_DIAGNOSTICS_ATTACHMENT_FILENAME
WINDOWS_SANDBOX_LOG_ATTACHMENT_FILENAME
Filename used for the Windows sandbox log feedback attachment.

Functions

emit_feedback_request_tags
emit_feedback_request_tags_with_auth_env