pub struct FeedbackUploadOptions<'a> {
pub classification: &'a str,
pub reason: Option<&'a str>,
pub tags: Option<&'a BTreeMap<String, String>>,
pub include_logs: bool,
pub extra_attachments: &'a [FeedbackAttachment],
pub extra_attachment_paths: &'a [FeedbackAttachmentPath],
pub session_source: Option<SessionSource>,
pub logs_override: Option<Vec<u8>>,
}Expand description
Inputs that control one feedback upload to Sentry.
The caller is responsible for applying any user-consent gate before setting
include_logs or passing diagnostic attachments. This type only describes
what to upload once that decision has been made.
Fields
classification: &'a strreason: Option<&'a str>include_logs: boolextra_attachments: &'a [FeedbackAttachment]Generated attachments that are already buffered and safe to upload.
These are included after codex-logs.log and before path-backed rollout
attachments. They are only passed by the caller after any user consent
gate has decided logs and diagnostics should be uploaded.
extra_attachment_paths: &'a [FeedbackAttachmentPath]session_source: Option<SessionSource>logs_override: Option<Vec<u8>>Auto Trait Implementations
impl<'a> Freeze for FeedbackUploadOptions<'a>
impl<'a> RefUnwindSafe for FeedbackUploadOptions<'a>
impl<'a> Send for FeedbackUploadOptions<'a>
impl<'a> Sync for FeedbackUploadOptions<'a>
impl<'a> Unpin for FeedbackUploadOptions<'a>
impl<'a> UnsafeUnpin for FeedbackUploadOptions<'a>
impl<'a> UnwindSafe for FeedbackUploadOptions<'a>